@@ -1,6 +1,6 @@
 from django.contrib import admin
 
-from .models import Dictionary, Newsletter
+from .models import Dictionary, Newsletter, RssFeed
 
 
 class NewsletterAdmin(admin.ModelAdmin):
@@ -12,5 +12,13 @@ class DictionaryAdmin(admin.ModelAdmin):
     list_display = ("word", "pronunciation")
 
 
+class RssFeedAdmin(admin.ModelAdmin):
+    search_fields = ("user", "feed")
+    list_display = ("user", "feed")
+    readonly_fields = ("feed",)
+    raw_id_fields = ("user",)
+
+
 admin.site.register(Newsletter, NewsletterAdmin)
 admin.site.register(Dictionary, DictionaryAdmin)
+admin.site.register(RssFeed, RssFeedAdmin)
